__code__='GatU0D/[on&>$QoP+t8J.4l7TQB:B8[<K8@Wi?C@NfYGF7s#OQ4^)!KB9S_XCpUa?>bpiqUjh8en^fh.[NP[N8G$eD]\\]3IkF#K!KM_U/C&UlV]Hr,1@7ZR$!hb(q!3ZD%*"#Mo=1"@m"0)DnUC(**X91?\\:B4,j:\'3BT:BGtGGREpsi#0<J^pAQtJEHpq!5AY!&,6mtf74Y;0*6S)GR<jpi"a%Q694YMb#nE<^\'&pc?s&%i*E7Y/W#DTq]W-R.nHLnCe_h==94g10!oLkfFcBk7K#C,\\``JjZO5l]STj/!?)27ih^p"1E6&RV;.Z%=`]<&``kn%e^i;CbJ=F`aW<VB/j9G_NAgo3>,LD@nuP^9-)JX&G4QcgABB24W^(QH2\\J(Rt4^>EBJH\\02EZ@TF;enP(*LlHGeVV#IfFZid9Ia+G%>;"(:1@:4W[Z%GYZoDG@$qhVAM:KF<\\(\\=G9-\'eF:9i7cgF+tNnR`\\L4$.E4=iS2"\'O-KmQk_EOQUC>0mjGqBq7^^WQViY#QsX!iQR8^s>p=bFLOOMML.+J>aR0NBAsJsnYHh,30A)M)hW\'0GN!s5:KdneaAYt;YBP"bt6uU-"m+5!FIt,58h.@XC[_m4:QFZ1MBA2u_h@&=_@&#Q@WKq:^7@H>nBm+IN*Q+%S/N<?-B\\cYREFqifT=!l%H,SuHg8eh:(*<[nVmKm82GL#K"Dcm4XEs$onULt"Nr\\bGf??t0-F!U5m_)NaUQg1&E&&BuE$m?>SXZhVltLe&]RJm%NMRRYhd3ne96\'UVbT:9n0X44t6(AToIbH[:d39M!q0QKrk7sBnN%C:*bH>Ji\\4CgC\\/QaKA]F=/DqX*7[ntr?U<2r<mK6Pemr!uQaK6SB\'c%9#RH>*8FLV&=SiFIe\'omEI&*/p&NEp"!CZ4ibQbDBK&sGa:ro\\kOf0srKg&TZ\'h@HP&CiM[ad=_t\\&D4SG@Mnjq(F=f5BRRYALJGb;puHLS]"pQd*@:D7gX[?[/o"8#k+8Kn2WXa$*"tN#I>7R-VA*/j160V^PC%^JIK"`I]F4VG]U.D^^ZGc&qr\\mH@TkVfj+!aX-Q88"!KO70Vu~>'



__code__='Gat=(s)6@U\'RuIZTe-\\a;IF;p4;_9\\Bb\'$$:"(qYKbTX(X<N?l@?]gL?!C7J2Wq\\1Q-)lkg+W?(p6Y0[ZVAjk%B44BcG$pbq=<m!&^:1/T^*E*MLR&4/JnLN7KEea(-!?o?mIuE3!R*bqusA,8A?LE"#pP<!^$QE&%DVL#^@-S*8j>;k5d49/cgD0\\.!ToE!>_Di+9\\SJ=cgJ"oK)(1VddVf)\\)@]Kn(b?8\\/:d@]%K&)qb?1^C>*$D[cE%Z[#$?N1JPQO^YRFr0WUQ9$3!2dt)4P&(t$@2OjD,*,I0IV#"X-l`9[UpWPo8#7$<VVVY,UrPdURGp%R*1iUoX33IdQV5,VJBMl"TIoA)P<h`InH<s/SnVBMg4?"\'j:CRYJh)1!5btj4-"5]$V&7u?JrOD=qjY8hCR]0Q1hS6\'80)HI$r<sY8KmJ;;9a.XVD?RPk:05LBu.\'$P&9M22=+mZm$J!:>A9RDfjHe>6r()r^Urqtn5_W)ME99]a65K33bBm8d)ur:G+LKj0lJST.$hi8Y[g*SchjPR?42?A*6THYMtUSLTh5%LS:,d%_PCAErj,R)i,.%L,pc\\^IY6RcEp[XQfRa4iAE==,"1(atqb6.?dXJ^fDYVN_DHs]FS&CF_$]/c(88tB\\CjTdOY1EE0S^,\'fJZ%jF&oMtl2YPo=\\aLJu`nl03Qr(h+l=S2(P<;m!(hNO%8N<TD<2WF_Xg`2FPf\\&"jF^T@j3D1`B_T*sA+1T#qbe01<G.`#,gkn$$1#=9H.#O.n/am[J&C\'JC/Q\'MmA?B,n!35YU2tCNU><&8?CAOa2s4nfGN\\B7qQ8WQrk[mu+0)1#B).,NVl>t3-!=8^n+X!\\MJhE.Y>:!XS6o8O/DTO!K^APIM8j417XK-d;cgV:oQun-ILGg1]NpbLIWs&<bcG"[G<:`sM&!gEp)C.nA:)k9pVPo"A7SZ@&)A%AQIs&DF^O9L[T,7*rgG0@F6e&sChJ+t<J/\\An)804T[(%Q6eb?q^H^2dWl\'X4V!5+sCD*tEV*&c<-Ds"@X>mH"f3,RmS^;qWcM+4f_tJK6gO^PA\'%0cPjYR`fA]@o6$bNWUj8OnD2[,dF5)!kinl+52IV+c&>;!\\#fNJgoU@gbN<uWZaebBq=.&#`~>'



__code__='Gas1]hbV`e&Dh8N56M,-P;c42@]5,H!@>`&UE3f6mS:WMR&XjmGC`AiXh/q!2"5V"qM4i!p!s)Z-YLRBS02-V^J&i`^=h2`f3`(PG72t@=>C"eG9$1F0ZqHc@AKe]Pg^[nB_NP!R)X5[YQ?>\\&hC:-CkReR0m8b?ZO&P3DZ,stVYA.Eq-*Tg3JLJj78CD0$U(&Dmn6mGZgkTAVV(97ifmQA7BGa4DY_1?d0E10#2i=D&P%J:;#$893hqd9&/:X/?gm.prDgbJ7;RMrdqNis.rn=DFf+hR3Nm+6lZa,?*G^M&HYH:A;$r9aYL-$6h&5I[XfjWAQBtW1/3PNNEoe_rZBFPnKgZ\'+ZAd"h4P\\%lPj*%qlY,&#:EmqXrV*B!Guk=@ab\'K8?E?cX=8P)0NXA*Um;0fdZ]h.X9+l&-@N(qO3X/ApCtVBhd3b)+]5H];\\a*iPY1nt>-U`=*Fh`.5nB<+H+>p>a"?-n]Ou-]>.+>P3Y4EnSWpX_nC\\>r<)+`44_nbGtjNL:#nGC@eGD>,NPY,7_X+uIc[`CBpDqk!G[V_o8npqU#4;Ges)%2XPP<],-+"\'R.F\'pSUT<6(!F:pI0G^ZAJLqGY*_50m:\\<(qF(!!305d)<orm1]C9NR&4CN6.4kk`.PH_jjQGg3$/r&mhrgDQW53qj?fMf[4:/M=\\,V_3!k,K3+4L$>A*NI)JK=KgS"gll@-9IKd%mdCD.mbh-oWPS69/p\'R[Q1HNDBQM3%6I+#A_/?oX::7Uh&V2tu56c+ppM<P`qV,$YTNQIIJ2=:gfKa9&dCBJ.BHh90k45DgQo4NcQf5Va>=%i_Ed^&O.ZRPLTX]aWh0Y$,UF?$R<#8EBp-;h##f"#pVCrqRHn\'-==l:ft?IZ*m!OZT1]9buH/%W:DmU@%Y00D_C,`:KR3KmIg9!7K6+].:E#4cA[5k2;,k^Gu3"=bruqNjg[nuFQP]uG0i(dB<g]NCs6ec,/>Zq5"GIfLFr>\\s~>'



__code__='Gas1]D/U@^&>$Qs4,t7`f+!F#995B*N5W8F6jOr(jglk\'A"pPO.Mm3<gh`-hc?ImRFlJq>:T;8KrWn"+T5e66(OT]SEn?Zo`SMW;GA!L[B"ZIh%<J0-1k26fr^@$0_AM3D\'S$1%JF0TB@f]KC1%8ZG4%KI8L\'_Moec>#d$\\/]%7DL8.3PZrV%fjoX?3"dB?3G\'H?34@9r"/?Qi(&;>"\'u$+"Ro@*X+8e%56JPn//MW]bk:J7X7.WZ>;342XE+To!a1.c\'?$q9@.T\'U08SEgr1$\\+;[t`oeG1:)S,RedAlTsT.Z5LLX>*]tau\\Ab(n:GEe?P5\\YG#m#_,`RC%\'[_l&o],SnnSmq^_%$>5q&Y<%pDpoAs&oJi5gH0600T+RE#@3nIsG,46PHmh2THj_^GD<O.LI;HsoN[:MZ4KUue>:W$\'M//%8CoDW`4dbt5K&2R]>E5rC\'aIo]MsB3KT<giMmFX5-bNh/]DTeNoRGVd".s:3)^@8]#VH*!W,dg7flKCXYif_Jcr%j@uH9k"XHu`&J3O^#Zc.VI"LfU7)ctONs7_2V^-AU"LuRZ2%cab1>t#15V8;G[\'m]i9A;m;VSOq^m@nJd7tC<ptCb;kPTM2:;61?%h9\'h<G[EHQK-"!a!T$h+ERDV?9%V"&4^oFCcP,i79G#/*<$b1#q<riTL$$7Mj9_X\\fsAn^R*W=s-\\?%g!+^Jgm9MPb]FiZ8eRCQEEsYs2s(`+;;VJP$9,9&]f=F]p#Ygjjh5hZLr)oab2;kiktp=7E.%ZQm5qdkXPWdHrp%2cGk5Y#5"/V4ZrE/(;F:?F^$NpM_C)6<SA_)eO-eS^P$iTgXQAnCIkQV$WXdJNTV&WmITHKdXd%0;]gpcHgJ2g_^$Pus6k9&>CK<sq*oE/o=aMFmW=&9kr@EcBU.&u(bSR<dl-CM/qhiqr;AAT;CB2p&fh.8U0SA5;->XGA\'>m_rI(qE*2;M`mZf6ns&\\4:BF-Z@.>:AnX\'3[g3/YQAG.!.k.e7mtOY3Ucb5o%HVj6!a7b=S.\\]j0nSQ<=glIqm(E5Fgs\'7h/>0jq>Y0qP%(+oeX<`N+GjFrWTIEA:a~>'



__code__='Gas1]gMYb8&=k*r=]Sct<S[541i1UIejHFlC(s*61f0\\h!3I/:&f44LK\'\'.O`Y?NG=11d^:Cba<r^_O6T>B.Y7@uV.Mm8]b&U"D[h3i=rL3rW4R/:0_q\'4/^0/@b]4Fj&#!!9e7[O29(!i1>[i5P>4O9Qg:\'@6es!&aio!*au3J8N)CJ4kF]!A4JG#ODH)&(h&u!4W+*!T6D^%fnlrr#"o:^eXta!F?!.%.FV/S:>E3f=g&o_6:doJ_\'nTj:%gfZ2l="L_kQVeh[]*&\\AMI3N).>%Td)gqk=d/iI$2g>p*2uX!4JnO"(^I3aN-^9`@-==\\=e-0JmFY(<m\'.!<]je+T]Ub0"s/."!#cD)2*%Q++P."N`fqm%6-6g]3DlSDWZcUO]7kt[UF1$^Rk=lNuecQYMZtl\\7_*8]2Al;X)]AU/K1%7\'&Bld/!od$.?`+!kI[=jSbreo761=QWa\\!=.erkKF2qGLk:5iEG5;jm`Hcs=S]9l(8#;>Z>[#E]+PNP?3hijeS1Go_QL?3;=SdL"pAJugPF0rp^AhXT`2=u_9lUp4S69C?I5;_/c\'%S?];&6.@6]oXWjE^]gRIVpOWEP,@)l+mP?aiQ.3])+SaO_tm:i,>fC\'e&*]g=TN.Ysp9ZN/fQp\\?%edm@W\'\'L`<lr;YYRRN+<_DF@N0+\\dpO@;HQYrYF@RUiuVJ%,HNY\\X8_qJ?quhC.kYWgkloBkf.i<;P*e__&%:,sF\\E$^<-r/8bpF6jM5.ZfBTFg<h,P4.E0f0?BtWJK$spq::Op2e];Kr8u;Ym;I:A8^T[gH\'i9EOs$WTepePO?UeNh3MYOYgf],Ygn$)(B&FGqE)25c;6jDMOLF!<U0IAurXRP$6?`\\/Mj;nbk!48@Lgl2\\oQ/E_O4&Hj-VoZg8;7cmkp-(>Pf?^]?>Go]<jS*b6Y?00$gP:$Sqr^5/2OT>,$AC[4V;P`W^J1g1KF&F`[K>YMcnVg05=:I@f")E/t7<d\\B@QZ<@N$ClL;F4\',=EK<A+&q&B=oR+^9n02Bj`nGq&G[EM-EG<RCcFV/1R0WimL(4C@4``J*HK0KZgI&P_:m5#,YC~>'
